@@ -1,15 +1,16 @@
-extern crate tokio_executor;
 extern crate futures;
+extern crate tokio_executor;
 
-use tokio_executor::*;
-use futures::{Future, future::lazy};
+use futures::{future::lazy, Future};
+use tokio_executor::DefaultExecutor;
 
 mod out_of_executor_context {
     use super::*;
+    use tokio_executor::Executor;
 
     fn test<F, E>(spawn: F)
     where
-        F: Fn(Box<Future<Item=(), Error=()> + Send>) -> Result<(), E>,
+        F: Fn(Box<Future<Item = (), Error = ()> + Send>) -> Result<(), E>,
     {
         let res = spawn(Box::new(lazy(|| Ok(()))));
         assert!(res.is_err());
